% ENGINE_DATA.m fuel and engine properties. Also, 
% - define input data for the fuel and emissions calculations,
% - makes polynomial functions for NOx and PM emissions
% - saves data to file 'emissionsdata.mat'
% - plots SFC and NOx and PM emissions over the engine load range
%   (optional)
% - saves plots (optional)

clear;
%% Define input data for fuel and engine
%  Engine loads 
Loadvec = [25 50 75 100];

% Specific fuel consumption for the fuels (g fuel/kWh) (read at 30, 50, 85
% and 100 % load)
SFC.HFO   = [9.40 8.73 8.61 8.67]/8.61 * 174;   % 174 g/kWh at optimum, from [#man-bw_2010a]. Ref. numbers from [#aesoyushakov_2013a] in MJ/kWh.
SFC.MGO   = [8.96 8.66 8.53 8.63]/8.53 * 154.4; % SFC for MGO @ 75 % MCR = 154.4 g/kWh from [#GL_2011a]. Ref. numbers from [#aesoyushakov_2013a] in MJ/kWh.
SFC.LNG   = [130.1 127.9 126.5 130.9];          % [#GL_2011a]

% Percent sulphur in the fuels
sulphur.HFO = 2.1 ;
sulphur.MGO = 0.05;
sulphur.LNG = 0   ;

% Fuel dependent emissions (CO2 and SOx):
% CO2 pollutant emission ratio (g CO2/kg fuel)
PER.CO2.HFO = 3200;                        % [#woud_2002a]
PER.CO2.MGO = 3200;                        % [#woud_2002a]
PER.CO2.LNG = 2743;                        % From stochiometric calc (see report)

% SOx pollutant emission ratio (g SOx/kg fuel per % S in fuel)
PER.SOx.HFO = 20 * sulphur.HFO; % 20 g SOx/kg fuel per % S in fuel (from [#woud_2002a])
PER.SOx.MGO = 20 * sulphur.MGO; % [#woud_2002a]
PER.SOx.LNG = 20 * sulphur.LNG; % [#woud_2002a]

% Combustion dependent emissions (NOx and PM):
% NOx reference factors for specific emissions (relative values from
% [#aesoyushakov_2013a]) 
relativevalues.NOx.HFO = [14.9 12.5 10.9 9.7]/10.9;   
relativevalues.NOx.MGO = [15.1 12.5 10.4 8.9]/10.4;  

% NOx base line specific emission values (g NOx/kWh)
refvalues.NOx.HFO = 12; % g/kWh, [#aesoystenersen_2013a]
refvalues.NOx.MGO = 11; % g/kWh, [#aesoystenersen_2013a]
refvalues.NOx.LNG = 5;  % g/kWh (from Vilmar)

% NOx specific emissions (g NOx/kWh)
SPE.NOx.HFO = relativevalues.NOx.HFO * refvalues.NOx.HFO; 
SPE.NOx.MGO = relativevalues.NOx.MGO * refvalues.NOx.MGO; 
SPE.NOx.LNG = relativevalues.NOx.MGO * refvalues.NOx.LNG; 

% Specific PM emissions (mg/kWh):
SPE.PM.HFO = [233 254 267 299];	% [#aesoyushakov_2013a]
SPE.PM.MGO = [ 79  76  83 108];	% [#aesoyushakov_2013a]
    % Taken at 50 and 100 % load:
SPE.PM.LNG = [     10       5];	% (from Vilmar)  

%% Generate polynomial functions for SFC, NOx and PM
p_SFC_HFO  = polyfit([30 50 75 100], SFC.HFO,2);
p_SFC_MGO  = polyfit([30 50 75 100], SFC.MGO,2);
p_SFC_LNG  = polyfit([30 50 75 100], SFC.LNG,2);

p_NOx_HFO  = polyfit(Loadvec, SPE.NOx.HFO,2);
p_NOx_MGO  = polyfit(Loadvec, SPE.NOx.MGO,2);
p_NOx_LNG  = polyfit(Loadvec, SPE.NOx.LNG,2);

p_PM_HFO  = polyfit(Loadvec, SPE.PM.HFO,3);     % 3poly
p_PM_MGO  = polyfit(Loadvec, SPE.PM.MGO,2);
p_PM_LNG  = polyfit([50 100], SPE.PM.LNG,1);    % Linear relationship

%% Save polynomial functions for SCF, NOx and PM, sulphur percentage and PER for later use
save('enginedata.mat','p_SFC*','p_NOx*','p_PM*','sulphur','PER','-v7.3');

%% Plot SFC, NOx and PM over engine load range, save plots (optional)
%{
% Evaluate polynomials to prepare for plotting
x = linspace(20,100);

sfc_HFO = polyval(p_SFC_HFO,x);
sfc_MGO = polyval(p_SFC_MGO,x);
sfc_LNG = polyval(p_SFC_LNG,x);

NOx_HFO = polyval(p_NOx_HFO,x);
NOx_MGO = polyval(p_NOx_MGO,x);
NOx_LNG = polyval(p_NOx_LNG,x);

PM_HFO = polyval(p_PM_HFO,x);
PM_MGO = polyval(p_PM_MGO,x);
PM_LNG = polyval(p_PM_LNG,x);

clf
%{
% Plot SFC
SFCchange = figure(1);
hold on
points = plot(  [30 50 75 100], SFC.HFO,'x', ...
                [30 50 75 100], SFC.MGO,'x', ...
                [30 50 75 100], SFC.LNG,'x');

poly   = plot(  x,sfc_HFO,'-', ...
                x,sfc_MGO,'-', ...
                x,sfc_LNG,'-');

xlabel('Engine load %')
ylabel('SFC [g/kWh]')
legend(poly,'HFO','MGO','LNG','Location','northeast')
title('Specific fuel consumption (SFC) for varying engine load')
saveas(SFCchange,'SFCchange.png')
%}

%{
% Plot NOx
NOxchange = figure(2);
hold on
points = plot(Loadvec, SPE.NOx.HFO,'x', ...
              Loadvec, SPE.NOx.MGO,'x', ...
              Loadvec, SPE.NOx.LNG,'x');

poly   = plot(x, NOx_HFO,'-', ...
              x, NOx_MGO,'-', ...
              x, NOx_LNG,'-');

xlabel('Engine load %')
ylabel('Specific NOx emissions [g/kWh]')
legend(poly,'HFO','MGO','LNG')
title('Specific NOx emissions for varying engine load')
saveas(NOxchange,'NOxchange.png')
%}

%{
% Plot PM
PMchange = figure(3);
hold on; box on;  grid on;
points = plot(Loadvec, SPE.PM.HFO,'x', ...
              Loadvec, SPE.PM.MGO,'x', ...
              [50 100], SPE.PM.LNG,'x');

poly   = plot(x, PM_HFO,'-', ...
              x, PM_MGO,'-', ...
              x, PM_LNG,'-');

xlabel('Engine load %')
ylabel('Specific PM emissions [mg/kWh]')
legend(poly,'HFO','MGO','LNG')
title('Specific emissions of particulate matter (PM)')
saveas(PMchange,'PMchange.png')
%}
%}
