function [H, V, Tnet, Ri] = hv(V,L,B,T,Lpar,phi,alpha,PB,Dp,K)

% HV.m calculates the ship performance in brash ice. In addition
% to the essential data (h & v) for generating ship performance
% in ice (h-v) curves, the algorithm can optionally return the
% information on net thrust (Tnet) and brash ice resistance (Ri)
% for a desired vessel. Finally, computed h-v plot is readily
% available.
%
% The script is based on a Matlab function made by Sandro Erceg for the
% Sustainable Arctic Sea Transport module given at Marine Technology
% department, NTNU. It was originally made for calculating ship performance
% in level ice, and has been edited to only consider performance in brash
% ice.
%
% The algorithm uses one subfunction:
% - ice_resistance.m: to compute ship resistance in brash ice according to
%   the formulation presented by Juva and Riska (2002).
% 
% ---------------------------------------------------------
% Outputs: [h, V, Tnet, Ri] + h-v plot
% 
% H         Ice thickness (vector or scalar)            m
% V         Attainble speed (vector or scalar)          kn
% Tnet      Net thrust vector                           kN
% Ri        Brash ice resistance (Juva and Riska, 2002) kN
% 
% h-v plot  Ice thickness vs. Ship speed (h-v) curve
% 
% ---------------------------------------------------------
% Inputs:
%
% V         Max ship speed in open water                kn
% 
% L         Ship length                                 m
% B         Ship breadth                                m
% T         Ship draft                                  m
% 
% Lpar      Parallel midbody length                     m
% phi       Stem angle at B/4                           deg
% alpha     Waterline entrance angle                    deg
% 
% PB        Engine power                                kW
% Dp        Propeller diameter                          m
% K         Empirical factor for bollard pull
%           (see Chapter 6 of Juva and Riska, 2002:
%           On the power requirement in the FSICR;
%           Research Report No. 53)
% 
% ---------------------------------------------------------
% Runa A. Skarb | runaaman@stud.ntnu.no | v 1.3 25 Nov 2014

etas = 0.99;                 % Transmission efficiency coefficient
PD   = PB*etas;              % Power delivered to the propeller, kW

Hmin = 0.4; % m (Ri only valid for h >= 0.4 m (Juva and Riska, 2002))
Hmax = 2  ; % m
h    = linspace(Hmin, Hmax, 200); % Ice thickness vector, m
Vvec = linspace(0, V, 200);       % Ship speed vector, kn
v    = V * 0.5144;                % kn to m/s conversion
vvec = Vvec * 0.5144;             % kn to m/s conversion

% Net thrust concept (see Juva and Riska, 2002)
Tnet   = K * (PD*Dp)^(2/3) * (1 - (1/3)*(vvec/v) - (2/3)*(vvec/v).^2);       % values in kN
p_Tnet = polyfit(Tnet,Vvec,2);

% Find resistance in ice for different ice thicknesses
Ri   = ice_resistance(h, phi, alpha, L, B, T, Lpar);
p_Ri = polyfit(h,Ri,2);

% Find attainable speed for each ice thickness (Tnet = Ri)
for i = 1:length(h)
    % Find Ri for current ice thickness
    R = polyval(p_Ri,h(i));
    % Find speed V from R(h(i)) = T(v(i))
    V(i) = polyval(p_Tnet,R);
    
    H(i) = h(i);
    if V(i) < 0
        V(i) = nan;
        H(i) = nan;
    end
end

V = V(isfinite(V));
H = H(isfinite(V));
Tnet = Tnet(isfinite(V));
Ri = Ri(isfinite(V));
end