function [Ri] = ice_resistance(H_M, phi2, alpha, L, B, T, Lpar)

% ICE_RESISTANCE.m calculates the ice resistance for the case vessel with
% the method of Juva and Riska, 2002.
%
% ----------------------------------------------------------------------
% Outputs: [Ri]
%
% Ri         Ice resistance in brash ice              kN
% 
% ----------------------------------------------------------------------
% Inputs:
% 
% H_M        Channel brash ice thickness (can be a    cm
%            vector or a scalar)                      
% phi2       Stem angle between the bow and the       deg
%            waterline at B/4                         
% alpha      Waterline entrance angle                 deg
% L          Ship length (between perpendiculars)     m
% B          Ship breadth                             m
% T          Ship draught                             m
% Lpar       Length of the parallel midbody at        m
%            midships                                 
%
% ----------------------------------------------------------------------
% Runa A. Skarb | runaaman@stud.ntnu.no | v1.0, 04 Nov 2014



H_F = 0.26 + (H_M * B).^0.5;

psi = atan(tan(phi2)/sin(alpha));

C_mu = 0.15 * cos(phi2) + sin(psi) * sin(alpha);
if C_mu < 0.45
    C_mu = 0.45;
end

C_psi = 0.047 * psi - 2.115;
if C_psi < 0
    C_psi = 0;
end

% For ice classes lower than 1A Super:
C1 = 0;
C2 = 0;

C3 = 845.576;   % kg/(m^2 s^2)
C4 = 41.74;     % kg/(m^2 s^2)

C5 = 825.6;     % kg/s

LTB = (L*T/B^2)^3;
if LTB > 20
    LBT = 20;
elseif LTB < 5
    LTB = 5;
end

Awf = 0.25 * L * B;

Ri = (C1 + C2 + C3.*(H_F + H_M).^2.*(B + C_psi + H_F).*C_mu + C4*Lpar*H_F.^2 ...
    + C5*LTB*Awf/L) *10^-3; % kN

end