function [V, Rt]  = ow_resistance(Lwl,B,T,V_max,S,plot_Rt,plot_coef)

% OW_RESISTANCE.m calculate open water resistance with Guldhammer-Harvald's
% method. The script is made from the approach as described in Amdahl et
% al, 2005.
%
% ----------------------------------------------------------------------
% Outputs: [Rt] (+ Rt-V plot + Ci-V plot optionally)
%
% Rt         Open water resistance             kN
%
% Rt-V plot  Open water resistance vs. ship speed
% Ci-V plot  Coefficients of resistance vs. ship speed
% ----------------------------------------------------------------------
% Inputs:
%
% Lwl        Ship length (on water line)       m
% B          Ship breadth                      m
% T          Ship draught                      m
% V_max      Max speed                         kn
% S          Wet surface                       m^2
%
% plot_Rt    Binary, = 1 if Rt-V plot desired,
%             = 0 otherwise
% plot_coef  Binary, = 1 if Ci-V plot desired,
%             = 0 otherwise
%
% ----------------------------------------------------------------------
% Runa A. Skarb | runaaman@stud.ntnu.no | v1.4, 04 Nov 2014

%% Initiation
g      = 9.81; % m^2/s
rho_sw = 1025; % kg/m^3

% Ship speed
V = 0:1:ceil(V_max); % kn
v = V * 0.5144; % Conversion from kn to m/s

% Froude's number
Fn = v / sqrt(g * Lwl); % [-]

% Reynold's number. Kinematic viscosity for water of 5 deg C:
Re = v * Lwl / (1.519*10^-6); % [-]

%% Calculations
% Coefficients matrix
C = zeros(6,length(Fn));

% Frictional resistance coefficient (ITTC'57 line):
C(1,:) = 0.075 ./ (log10(Re) - 2).^2;

% Residual resistance coefficienct. Values from diagram on p. F-4 of
% [#amdahlendal_2005a] for L/voldispl^(1/3) = 5.0 and C_P = 0.8). The
% diagram does not display C_R for Fn < 0.15 (V = 14 kn).
C(2,2:14)  = 0.6*10^-3;
C(2,15:17) = [0.79 1.0 1.14]*10^-3;

% Corrections
 
    % Scale effects. Table on p. 197 [#amdahlendal_2005a]. Interpolate
    % between L = 200 and L = 250:
    C(3,:) = (0 + (Lwl-200)/(250-200)*(-0.2 - 0))*10^-3;
    
    % B/T corrections
    C(4,:) = (0.16 * ((B/T) - 2.5))*10^-3;
    
    % Hull shape. Assumed "normal" hull shape.
    C(5,:) = 0;
    
    % Bulbous bow. Table on p. 199 in [#amdahlendal_2005a] for C_P = 0.8.
    % Interpolate between Fn = 0.15 and 0.18.
    for i = 2:length(Fn)
        
        if Fn(i) < 0.15
        C(6,i) = 0;
        
        elseif Fn(i) == 15
        C(6,i) = 0.1*10^-3;
        
        else
        C(6,i) = (0.1 + (Fn(i)-0.15)/(0.18-0.15)*(0-0.1))*10^-3;
        
        end
    end
    
% Zero for all coefficients at v = 0 kn
C(:,1) = 0;

% Total resistance coefficient:
C_T = sum(C);

% Total resistance:
Rt = 0.5 * rho_sw * S .* v.^2 .* C_T *10^-3; % kN

% Frictional resistance:
% Rf = 0.5 * rho_sw * S .* (V .* 0.5144).^2 .* C_F;

%% Plot
if plot_Rt == 1 || plot_coef == 1
    close all
end

% Total resistance plot
if plot_Rt == 1
    rr = figure;
    plot(V,Rt);
    title('Open water resistance for the case ship')
    xlabel('Speed [kn]')
    ylabel('Total resistance [kN]')
    %saveas(rr,'ow_resistance','png')
end 

% Plot of coefficients
if plot_coef == 1
    
    % Positive components:
    fh(1) = figure; 
    hP    = bar(V,C'.*(C'>0),'stacked'); 
    ahP   = gca; 

    % Negative components:
    fh(2) = figure; 
    hN    = bar(V,C'.*(C'<0),'stacked'); 
    
    % Total C_T
    fh(3) = figure;
    hC    = plot(V(2:length(V)),C_T(2:length(V)),'k','LineWidth',2.0);
        
    % Clean up
    set([hP,hN,hC],'parent',ahP); 
    close(fh(2));close(fh(3));
    
    axis([0 17 -0.3*10^-3 4*10^-3]);
	xlabel('Speed [kn]')
	ylabel('C_i [-]')
	title('Frictional coefficients for determining open water resistance for the case ship')
	legend('C_F, frictional','C_R, residual','C_{scale}, scale effects', ...
         'C_{BT}, breadth/draught relationship', 'C_{frame}, frame shape', ...
         'C_{bulb}, bulbous bow','Location','north')
    %saveas(fh(1),'resistance_coef','png')
end