% ROUTEDATA.m inports route data from files. The data is saved as geopoint
% vectors. The script requires the Mapping Toolbox. Routes can also be
% plotted (optional).
%
% Requirements:
% - Mapping Toolbox

%% Import route data
% Import route data from .gpx files in the 'data' directory
cd data
% The gpxread function returns an n-by-1 geopoint vector where n is the
% number of waypoints or points that define a route or track
route.NSR = gpxread('NSR_waypoints.gpx');
route.SCR = gpxread('SCR_waypoints.gpx');
cd ..

% Flip and start routes in Murmansk (not Tianjin)
route.NSR = flipud(route.NSR);
route.SCR = flipud(route.SCR);

%% Save route data coords as double (to access coordinates without Mapping Toolbox)
route.legcoordinates.NSR = [route.NSR.Latitude; route.NSR.Longitude]';
route.legcoordinates.SCR = [route.SCR.Latitude; route.SCR.Longitude]';

%% Replace NSR Arctic coordinates with ice data points
icedata = load('icedata.mat');
coord.CapeKaninNos = [68.8 43.2];

% Find ice data points east of CKN
i_startice = find(icedata.ice_coord(:,2) > coord.CapeKaninNos(2)); % Find indexes
i_startice = i_startice(1); % Index of first point east of CKN

% Find route data points east of CKN
i_startroute = find(route.legcoordinates.NSR(:,2) > coord.CapeKaninNos(2)); % Find indexes
i_startroute = i_startroute(1); % Index of first point on route after CKN

% Find route data points south of ice data
coord.stopice = icedata.ice_coord(length(icedata.ice_coord),:); % Coordinates of last ice data point
i_stoproute  = find(route.legcoordinates.NSR(:,1) < coord.stopice(1)); % Indexes of points on route south of last ice data point
i_stoproute  = i_stoproute(1)-1; % Index of last point on route before south of ice area

% All points from i_startroute to (and including) i_stoproute to be
% replaced by ice data points

% Replace route coordinates between these points with ice data coordinates
coordsbefore = route.legcoordinates.NSR([1:i_startroute-1],:);
coordsmiddle = icedata.ice_coord;
coordsafter  = route.legcoordinates.NSR([i_stoproute+1:length(route.legcoordinates.NSR)],:);

route.legcoordinates.NSRnew = [coordsbefore; ...
                               coordsmiddle; ...
                               coordsafter];
       
%% Find the geographic properties of the routes

% Get port coordinates
coord.Murmansk  = [route.NSR(1).Latitude                 route.NSR(1).Longitude];
coord.Tianjin = [route.NSR(length(route.NSR)).Latitude   route.NSR(length(route.NSR)).Longitude];

% Find course and distance for each leg
[course.NSRnew, dist.NSRnew] = legs(route.legcoordinates.NSRnew);
[course.SCR, dist.SCR]       = legs(route.SCR.Latitude, route.SCR.Longitude);

dist.NSRtot = sum(dist.NSRnew);
dist.SCRtot = sum(dist.SCR);

%% Save route data in file 'routedata.mat'
save('routedata.mat','route','coord','dist','i_startice','i_startroute','-append','-v7.3'); % append, routegen.m also writes to 'routedata.mat'

%% Plot routes data in map
% Comment out to plot:
%{
% Generate map
routes = worldmap([  0   80], ...
                  [-15 -165]);
title('Generated routes for the case vessel')

% Display coast lines
%load coast
%plotm(lat, long,'Color','blue')

% Display land areas as black
geoshow('landareas.shp','FaceColor','black')

% Display topography
% load topo
% geoshow(topo, topolegend, 'DisplayType', 'texturemap')
% demcmap(topo)

% Plot routes
r1 = geoshow(route.NSR.Latitude, route.NSR.Longitude, 'DisplayType', 'line', ...
        'Color', 'r', 'LineWidth', 1.5);
r2 = geoshow(route.SCR.Latitude, route.SCR.Longitude, 'DisplayType', 'line', ...
        'Color', 'b', 'LineWidth', 1.5, 'LineStyle', '--');
legend([r1 r2],'Northern Sea Route','Suez Canal Route','Location','best')
    
% Plot cities
geoshow(coord.Murmansk(1), coord.Murmansk(2), 'DisplayType', 'point', ...
        'MarkerEdgeColor', 'y', 'MarkerFaceColor', 'auto', 'Marker', 'o')
geoshow(coord.Tianjin(1), coord.Tianjin(2), 'DisplayType', 'point', ...
        'MarkerEdgeColor', 'y', 'MarkerFaceColor', 'auto', 'Marker', 'o')

% Label cities
textm(coord.Murmansk(1)-12,coord.Murmansk(2)-10,'Murmansk','BackgroundColor','w')
textm(coord.Tianjin(1)+7,coord.Tianjin(2)-15,'Tianjin','BackgroundColor','w')

% Uncomment to save map as .png-file
%saveas(routes,'routes','png')
%}