function [T, fc, emissions, energy] = sail_ice(distance, ice_c, h, fueltype)

% SAIL_ICE.m calculates time, fuel consumption and emissions for a given
% leg in ice on a route. The leg is divided in an open water and an ice
% part, as weighted by the ice consentration. The output is found
% separately for the open water and the ice part, and then summed in the
% end.
%
% -------------------------------------------------------------------
% Input
%
% distance   Sailing distance                        nm
% ice_c      Ice consentration                       percent
% h          Ice thickness                           cm                                          
% fueltype   Type of fuel used on leg (HFO, MGO or
%            LNG), input as string    
%
% -------------------------------------------------------------------
% Output
%
% T          Total sailing time on leg               days
% fuelcons   Total fuel consumption on leg           tonnes
% emissions  Total emissions of CO2, SOx, NOx and    tonnes
%            PM for the whole leg
% energy     Energy consumption for leg              kWh
% -------------------------------------------------------------------
% Runa A. Skarb | runaaman@stud.ntnu.no | v1.2 03 Dec 2014

% Vessel info
V_s = 14.5; % kn
PB = 13560;     % Brake power, kW
etas = 0.99;    % Transmission efficiency coefficient
PD = etas * PB; % Power delivered to the propeller, kW

% If ice thickness < 40 cm or no ice, open water sailing is assumed
if (h < 40) || (ice_c == 0)
    [T, fc, emissions, energy] = sail_ow(V_s, distance, fueltype);
    return
end

% Distance sailed in ice and ow
dist_ice  = (ice_c/100) * distance;
dist_ow = (1-(ice_c/100)) * distance;

%% Open water sailing
emissions_ow = zeros(1,4);
[T_ow, fc_ow, emissions_ow(:), energy_ow] = sail_ow(V_s, dist_ow, fueltype);

%% Sailing in ice
hvdata = load('hv.mat');
shipdata = load('shipdata.mat');

% Ice sailing on leg
V_ice = interp1(hvdata.h, hvdata.V, h/100, 'cubic');
if V_ice < 3
    error(sprintf('Speed in ice below minimum requirement of 3 knots, V = %2.0f for h = %2.0f cm"',V_ice,h));
    return
elseif V_ice > V_s
    error(sprintf('Speed in ice above service speed, V = %2.0f',V_ice));
    return
end
T_ice = dist_ice / V_ice; % hrs

% Resistance
R_ice = interp1(hvdata.h, hvdata.Ri, h/100, 'cubic'); % kN
R_ow  = interp1(shipdata.V_vec, shipdata.Row, V_ice, 'cubic'); % kN
R_tot = R_ow + R_ice; % kN

% Required power
PE = R_tot * (V_ice * 0.5144); % Convert V to m/s. Pe [kW]
%PE = R_tot * convvel(V_ice, 'kts','m/s'); % kW

% MCR
MCR = PE / PB * 100; % percent
if MCR < 0 || MCR > 100
    error(sprintf('MCR out of range: MCR = %2.0f. Must be between 0 and 100 %%.',MCR));
    return
end

% Energy used on ice part of leg
energy_ice = PE * T_ice; % kWh

% Find SFC for fuel type
SFCvar = sprintf('p_SFC_%s', fueltype);
engdata = load('enginedata.mat');
SFC_ice = polyval(engdata.(SFCvar), MCR); % g/kWh

% Fuel consumption on leg
fc_ice = energy_ice * SFC_ice * 10^-3; % kg fuel

% Emissions from ice part of leg
emissions_ice(:,:) = emissions_calc(fc_ice, energy_ice, MCR, fueltype); % [g g g mg] [CO2 SOx NOx PM]

%% Total (incl conversions)
T = T_ow + T_ice / 24;    % days
fc = fc_ow + fc_ice * 10^-3;   % tonnes
emissions_ice(4) = emissions_ice(4) * 10^-3; % tonnes PM
emissions = emissions_ow + emissions_ice * 10^-6;  % tonnes   

energy = energy_ice + energy_ow; % kWh

end