function [T, fuelcons, emissions, energy] = sail_ow(V, distance, fueltype)

% SAIL_OW.m calculates time, fuel consumption and emissions for a given
% open water leg on a route. The speed is fixed for the whole leg.
% 
% -------------------------------------------------------------------
% Input
%
% V          Sailing speed (constant on leg)         kn
% distance   Sailing distance                        nm
% fueltype   Type of fuel used on leg (HFO, MGO or
%            LNG), input as string    
%
% -------------------------------------------------------------------
% Output
%
% T          Total sailing time on leg               days
% fuelcons   Total fuel consumption on leg           tonnes
% emissions  Total emissions of CO2, SOx, NOx and    tonnes 
%            PM for the whole leg                       
% energy     Energy consumption for leg              kWh
%
% -------------------------------------------------------------------
% Runa A. Skarb | runaaman@stud.ntnu.no | v1.1 28 Nov 2014

PB = 13560;     % Brake power, kW
etas = 0.99;    % Transmission efficiency coefficient
PD = etas * PB; % Power delivered to the propeller, kW

% Sailing time on leg
T = distance / V; % hrs

ship = load('shipdata.mat');

% Resistance at given speed interpolated from total resistance curve
R = interp1(ship.V_vec, ship.Row,V); % kN

% Necessary power to attain given speed
PE = R * (V * 0.5144); % Convert V to m/s. Pe [kW]
%PE = R * convvel(V, 'kts','m/s'); %kW

% Total energy used on leg
energy = PE * T; % kWh

% Engine load
MCR = PE/PB * 100; % percent
if MCR < 0 || MCR > 100
    error(sprintf('MCR out of range: MCR = %2.0f. Must be between 0 and 100 %%.',MCR));
    return
end

% Find SCR for fuel type
SFCvar = sprintf('p_SFC_%s', fueltype);
eng = load('enginedata.mat');
SFC = polyval(eng.(SFCvar), MCR); % g/kWh

% Fuel consumption on leg
fuelcons = energy * SFC * 10^-3; % kg fuel

% Emissions on leg
emissions(:,:) = emissions_calc(fuelcons, energy, MCR, fueltype); % [g g g mg] [CO2 SOx NOx PM]

% Conversion
T = T / 24; % days
fuelcons = fuelcons * 10^-3; % tonnes
emissions = emissions * 10^-6;   % tonnes
emissions(4) = emissions(4) * 10^-3; % tonnes PM

end