% SIMULATE_SAILING.m simulates the sailing for the whole time period. It
% considers ECA areas, choice of route and sailing in ice. 
%
% ---------------------------------------------------------
% Runa A. Skarb | runaaman@stud.ntnu.no | v 1.9 11 Dec 2014

clear; clc;
%% Load relevant files
icedata = load('icedata.mat');
hvdata = load('hv.mat');
shipdata = load('shipdata.mat');
routedata = load('routedata.mat');
scenarios = load('scenarios.mat');
costsdata = load('costs.mat');
atechdata = load('abatementtech.mat');

%% Initial and boundary conditions
% Time period (in serial date number format (number of days))
startsimtime = icedata.ice_dates(1);    
%{
endsimtime   = icedata.ice_dates(length(icedata.ice_dates));
duration  = endsimtime - startsimtime;
%}
% Change duration to one year (not measurements)
duration = 365; % days
endsimtime = startsimtime + duration;

% Find max ice thickness that the vessel can do 3 kn
min_speed = 3; % kn
h_maxpossible = interp1(hvdata.V, hvdata.h, min_speed, 'cubic') * 100; % cm

% Determine when the vessel can sail NSR
maxiceT = max(icedata.ice_t); % Max ice thickness along route for each date
cansailNSR = (maxiceT <= h_maxpossible); % Find for which measured dates vessel can sail

% Interpolate to find when must stop sailing NSR (when maxiceT > maxiceTpossible)
startcount = 0;
stopcount = 0;
for j = 1:length(cansailNSR)-1
    if ~cansailNSR(j) && cansailNSR(j+1) % If ice thickness declines
        startcount = startcount + 1;
        startsaildate(startcount) = ceil(interp1(maxiceT(j:j+1), ...
                                                 icedata.ice_dates(j:j+1), ...
                                                 h_maxpossible, ...
                                                 'linear'));
    elseif cansailNSR(j) && ~cansailNSR(j+1) % If ice thickness grows
        stopcount = stopcount + 1;
        stopsaildate(stopcount)   = floor(interp1(maxiceT(j:j+1), ...
                                                  icedata.ice_dates(j:j+1), ...
                                                  h_maxpossible, ...
                                                  'linear'));
    end
end

% Find legs on NSR with ice
icestartidx = routedata.i_startice; % index of ice vector where ice starts
numicelegs = length(icedata.ice_coord) - icestartidx; % number of legs with ice
routeicestartidx = routedata.i_startroute;  % index of NSR route vector (new) where ice starts

% Define scenario for simulation
possiblescenarios = cellstr({'basecase','scenone','scentwo','scenthree'});

% Position vector for ship
posvec = cellstr({'Murmansk','Tianjin'});

% Annualisation factor
r = costsdata.discountrate * 0.01;
FAP = (r * (1 + r)^costsdata.lifespan) / ((1 + r)^(costsdata.lifespan - 1));


%% Sailing simulations

% Create empty structure array to save results
simulationresults = struct;

for scenarionumber = 1:length(possiblescenarios) % For each scenario
    
    % Initiation
    tic;
    tripsMT = 0;
    tripsTM = 0;
    numtrips = 0;
    
    % Start position Murmansk for each scenario
    pos = 1;
    
    % Current scenario specifications 
    scenarioname = char(possiblescenarios(scenarionumber));
    burnfuel = scenarios.(scenarioname).fuel;
    burnECAfuel = scenarios.(scenarioname).ECAfuel;
    
    % Set time counter to start of time period
    time = startsimtime;
    
    % Create variables for saving scenario data
    scenariofc = struct;
    scenariofc.(burnfuel) = zeros(1,2);
    scenariofc.(burnECAfuel) = zeros(1,2);
    scenarioem = zeros(2,4);
    
    if ~strcmp(scenarioname,'basecase') % All scenarios except base case

        while time < stopsaildate % sail NSR in the allowed operation window
            sailNSR;
        end

        % Save total number of trips on NSR
        simulationresults.(scenarioname).totals.trips.NSR = numtrips;

        % When time > stopsaildate, the vessel sails only on the SCR
        % for the rest of the time period. The results from sailing the SCR
        % is constant. Therefore, only one simulation is performed.
        sailSCR;

    else % for base case scenario only
        sailSCR;

        simulationresults.(scenarioname).totals.trips.NSR = 0;

    end
    
    % Find number of times the scenario sails the SCR
    remainingtime   = endsimtime - time; % time remaining in simulation time period
    sailtimeSCR     = simulationresults.(scenarioname).tourdata(numtrips).duration;
    remainingtrips  = remainingtime / sailtimeSCR;
    
    % Save totals for each voyage in the scenario
    simulationresults.(scenarioname).totals.trips.SCR   = 1 + remainingtrips;
    simulationresults.(scenarioname).totals.trips.total = simulationresults.(scenarioname).totals.trips.SCR + simulationresults.(scenarioname).totals.trips.NSR;
    switch scenarionumber
        case 1
            simulationresults.(scenarioname).totals.emissions = voyageem * simulationresults.(scenarioname).totals.trips.SCR;
        otherwise
            simulationresults.(scenarioname).totals.emissions = scenarioem + voyageem * remainingtrips;
    end
    
    % If ECA fuel = normal fuel
    if strcmp(burnfuel,burnECAfuel)
        simulationresults.(scenarioname).totals.fuelconsumption.(burnfuel)      = scenariofc.(burnfuel);

        simulationresults.(scenarioname).totals.costs.fuel.(burnfuel)    = costsdata.fuelprice.(burnfuel) * scenariofc.(burnfuel);
        
        simulationresults.(scenarioname).totals.costs.fuel.totalfuelcost = simulationresults.(scenarioname).totals.costs.fuel.(burnfuel);
    else
        simulationresults.(scenarioname).totals.fuelconsumption.(burnfuel)      = scenariofc.(burnfuel);
        simulationresults.(scenarioname).totals.fuelconsumption.(burnECAfuel)   = scenariofc.(burnECAfuel);

        simulationresults.(scenarioname).totals.costs.fuel.(burnfuel)    = costsdata.fuelprice.(burnfuel) * scenariofc.(burnfuel);
        simulationresults.(scenarioname).totals.costs.fuel.(burnECAfuel) = costsdata.fuelprice.(burnECAfuel) * scenariofc.(burnECAfuel);
 
        simulationresults.(scenarioname).totals.costs.fuel.totalfuelcost = simulationresults.(scenarioname).totals.costs.fuel.(burnfuel) + simulationresults.(scenarioname).totals.costs.fuel.(burnECAfuel);
    end
    
    % Find costs
    simulationresults.(scenarioname).totals.costs.capex = costsdata.capex.(scenarios.(scenarioname).SOxtech) + costsdata.capex.(scenarios.(scenarioname).NOxtech);
    simulationresults.(scenarioname).totals.costs.fees  = (costsdata.fee.SuezCanal * simulationresults.(scenarioname).totals.trips.SCR) + (costsdata.fee.NSR * simulationresults.(scenarioname).totals.trips.NSR);
    simulationresults.(scenarioname).totals.costs.opex  = costsdata.opex.addmaint.(scenarios.(scenarioname).SOxtech) + costsdata.opex.addmaint.(scenarios.(scenarioname).NOxtech) + simulationresults.(scenarioname).totals.costs.fees + simulationresults.(scenarioname).totals.costs.fuel.totalfuelcost(2);
    if strcmp(scenarios.(scenarioname).NOxtech,'SCRe')
        % Add 10 % of fuel cost to OPEX as cost of urea
        simulationresults.(scenarioname).totals.costs.opex = simulationresults.(scenarioname).totals.costs.opex + 0.1 * simulationresults.(scenarioname).totals.costs.fuel.totalfuelcost(1);
    end
    simulationresults.(scenarioname).totals.costs.note  = 'Note: OPEX contains fees and total fuel costs for scenario';
    
    % Equivalent annual costs
    simulationresults.(scenarioname).totals.costs.EAC = simulationresults.(scenarioname).totals.costs.capex * FAP + simulationresults.(scenarioname).totals.costs.opex;

    % NPV
    cashflow(1) = simulationresults.(scenarioname).totals.costs.capex;
    cashflow(2:costsdata.lifespan) = simulationresults.(scenarioname).totals.costs.opex;
    rate = r;
    NPV = 0;
    for year = 1:costsdata.lifespan
        NPV = NPV + cashflow(year)/(1+rate)^(year-1);
    end
    simulationresults.(scenarioname).totals.costs.NPV = NPV;
    
    % Cost effectiveness per emission
    reducedemissions = simulationresults.(scenarioname).totals.emissions(1,:) - simulationresults.(scenarioname).totals.emissions(2,:);
    simulationresults.(scenarioname).totals.costs.CER = simulationresults.(scenarioname).totals.costs.EAC ./ reducedemissions;
end

simulationresults.simulationtime = toc;
simulationresults.date = datestr(now);

%% Save results
simdate = datestr(now,30);
% What has changed:
revision = ('In sail_ice.m, changed dist_ice (was reversed)');
filename = sprintf('results_%s.mat',simdate);

save(filename,'-struct','simulationresults','-v7.3')
save(filename,'possiblescenarios','revision','-v7.3','-append')